History

Struct History 

pub struct History<S: Scalar, H: Fn(S) -> Vec<S>> { /* private fields */ }
History storage for DDE solver.

Stores computed solution steps and provides interpolation for accessing y(t - τ) at arbitrary past times.

Implementations

Source

impl<S: Scalar, H: Fn(S) -> Vec<S>> History<S, H>

pub fn new(initial_history: H, t0: S, dim: usize) -> Self

Create a new history with initial function.

pub fn add_step(&mut self, step: HistoryStep<S>)

Add a completed step to the history.

pub fn evaluate(&self, t: S) -> Vec<S>

Get the state at time t using interpolation.

pub fn evaluate_derivative(&self, t: S) -> Vec<S>

Get the derivative at time t using interpolation.

pub fn current_time(&self) -> S

Get the current end time of the computed solution.

pub fn n_steps(&self) -> usize

Number of stored steps.

pub fn clear(&mut self)

Clear history (keep initial function).