pub struct History<S: Scalar, H: Fn(S) -> Vec<S>> { /* private fields */ }Expand description
History storage for DDE solver.
Stores computed solution steps and provides interpolation for accessing y(t - τ) at arbitrary past times.
Implementations
Sourceimpl<S: Scalar, H: Fn(S) -> Vec<S>> History<S, H>
impl<S: Scalar, H: Fn(S) -> Vec<S>> History<S, H>
Sourcepub fn new(initial_history: H, t0: S, dim: usize) -> Self
pub fn new(initial_history: H, t0: S, dim: usize) -> Self
Create a new history with initial function.
Sourcepub fn evaluate_derivative(&self, t: S) -> Vec<S>
pub fn evaluate_derivative(&self, t: S) -> Vec<S>
Get the derivative at time t using interpolation.
Sourcepub fn current_time(&self) -> S
pub fn current_time(&self) -> S
Get the current end time of the computed solution.